@@ -83,7 +83,7 @@ def show_metric_dimensions(data):
     if len(data['metrics']) > 1:
         commondimensions = data['metrics'][0]['dimensions']
         for metric in data['metrics'][1:]:
-            for k in commondimensions.keys():
+            for k in tuple(commondimensions):
                 if k not in metric['dimensions'].keys() or \
                         commondimensions[k] != metric['dimensions'][k]:
                     del commondimensions[k]
@@ -166,7 +166,7 @@ class GraphMetric(tables.LinkAction):
             dimensions = datum['metrics'][0].get('dimensions', {})
             query = "?metric=%s" % metric
             for key, value in dimensions.items():
-                query += "&dim_%s=%s" % (key, value)
+                query += "&%s=%s" % (key, value)
         except AttributeError:
             # Catches case where Grafana 2 is not enabled.
             name = datum['metrics'][0]['name']
