@@ -27,7 +27,6 @@ from django.utils.dateparse import parse_datetime
 from django.utils.translation import ugettext as _  # noqa
 from django.utils.translation import ugettext_lazy
 from django.views.generic import View
-import six
 
 from horizon import exceptions
 from horizon import forms
@@ -103,12 +102,12 @@ def generate_status(request):
         service_alarms = alarms_by_service.setdefault(service, [])
         service_alarms.append(a)
     for row in SERVICES:
-        row['name'] = six.text_type(row['name'])
+        row['name'] = str(row['name'])
         for service in row['services']:
             service_alarms = alarms_by_service.get(service['name'], [])
             service['class'] = get_status(service_alarms)
             service['icon'] = get_icon(service['class'])
-            service['display'] = six.text_type(service['display'])
+            service['display'] = str(service['display'])
     return SERVICES
 
 
